@@ -1,8 +1,5 @@
 qprodnormalProdclin<-
     function(p, mu.x, mu.y, se.x, se.y, rho=0, lower.tail=TRUE){
-        library.dynam("RMediation",PACKAGE="RMediation")
-        ##      mu.x <- mu.x/se.x
-        ##      mu.y <- mu.y/se.y
         if (!lower.tail)
             p <- 1-p
         ans <- .Fortran('quantile_prodclin', p=as.numeric(p), mu.x=as.numeric(mu.x), mu.y=as.numeric(mu.y), se.x=as.numeric(se.x),se.y=as.numeric(se.y), rho=as.numeric(rho),  answer=numeric(1), ier=integer(1), abserr=numeric(1), last=integer(1)) # Return the value of the result parameter
